AudioXBlock
===========

This is a simple XBlock which will play audio files as an HTML5 audio
element. If unavailable, it will fall back to an embed element.

Usage: 

    <audio src="http://server.tld/static/song.mp3" />
